@@ -1,22 +1,30 @@
-from django.forms.widgets import CheckboxInput
+from django.forms.widgets import CheckboxInput, CheckboxSelectMultiple, RadioSelect
 from django.template import Context
 from django.template.loader import get_template
 from django import template
 from django.utils.safestring import mark_safe
 from django.conf import settings
 
-BOOTSTRAP_DEFAULT_VERSION = '1.4.0'
+BOOTSTRAP_DEFAULT_VERSION = '2.0.0'
 
 BOOTSTRAP_VERSION = getattr(settings, 'BOOTSTRAP_VERSION',
     BOOTSTRAP_DEFAULT_VERSION
 )
 
 BOOTSTRAP_BASE_URL = getattr(settings, 'BOOTSTRAP_BASE_URL',
-    'http://twitter.github.com/bootstrap/%s/' % BOOTSTRAP_VERSION
+    'http://twitter.github.com/bootstrap/assets/'
+)
+
+BOOTSTRAP_JS_BASE_URL = getattr(settings, 'BOOTSTRAP_JS_BASE_URL',
+    BOOTSTRAP_BASE_URL + 'js/'
+)
+
+BOOTSTRAP_CSS_BASE_URL = getattr(settings, 'BOOTSTRAP_CSS_BASE_URL',
+    BOOTSTRAP_BASE_URL + 'css/'
 )
 
 BOOTSTRAP_CSS_URL = getattr(settings, 'BOOTSTRAP_CSS_URL',
-    BOOTSTRAP_BASE_URL + 'bootstrap.min.css'
+    BOOTSTRAP_CSS_BASE_URL + 'bootstrap.css'
 )
 
 register = template.Library()
@@ -34,8 +42,8 @@ def bootstrap_stylesheet_tag():
 @register.simple_tag
 def bootstrap_javascript_url(name):
     # URL to Bootstrap javascript file
-    # http://twitter.github.com/bootstrap_toolkit/1.3.0/bootstrap_toolkit-dropdown.js
-    return BOOTSTRAP_BASE_URL + 'bootstrap-' + name + '.js'
+    # http://twitter.github.com/bootstrap/assets/js/bootstrap-<name>.js
+    return BOOTSTRAP_JS_BASE_URL + 'bootstrap-' + name + '.js'
 
 @register.simple_tag
 def bootstrap_javascript_tag(name):
@@ -73,13 +81,17 @@ def is_enabled(field):
     return not is_disabled(field)
 
 @register.filter
-def input_type(field):
+def bootstrap_input_type(field):
     widget = field.field.widget
     bootstrap_input_type = getattr(widget.attrs, 'bootstrap_input_type', None)
     if bootstrap_input_type:
         return bootstrap_input_type
     if isinstance(widget, CheckboxInput):
         return u'checkbox'
+    if isinstance(widget, CheckboxSelectMultiple):
+        return u'multicheckbox'
+    if isinstance(widget, RadioSelect):
+        return u'radioset'
     return u'default'
 
 @register.simple_tag
@@ -90,9 +102,21 @@ def active_url(request, url, output=u'active'):
     return ''
 
 @register.filter
-def as_bootstrap_choices(html_ul):
+def as_bootstrap_choices(field):
     # Nasty hack to make widgets with choices behave
-    return mark_safe(str(html_ul).replace('<ul>', '<ul class="inputs-list">'))
+    type = bootstrap_input_type(field)
+    if type == "radioset":
+        type = "radio"
+    elif type == "multicheckbox":
+        type = "checkbox"
+    else:
+        type = ""
+    choices = str(field).replace('<ul>', '')
+    choices = choices.replace('</ul>', '')
+    choices = choices.replace('<li>', '')
+    choices = choices.replace('</li>', '')
+    choices = choices.replace('<label', '<label class="%s"' % type)
+    return mark_safe(choices)
 
 @register.filter
 def pagination(page, range=5):
@@ -109,4 +133,4 @@ def pagination(page, range=5):
             'range_min': range_min,
             'range_max': range_max,
         })
-    )
\ No newline at end of file
+    )
